from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, Boolean, File, Int, Float, Directory

Toil_Cwl_Runner_V0_1_0 = CommandToolBuilder(tool="toil_cwl_runner", base_command=["toil-cwl-runner"], inputs=[ToolInput(tag="in_not_strict", input_type=String(optional=True), prefix="--not-strict", doc=InputDocumentation(doc="Enable loading and running development versions of CWL")), ToolInput(tag="in_user_space_docker_cmd", input_type=String(optional=True), prefix="--user-space-docker-cmd", doc=InputDocumentation(doc="(Linux/OS X only) Specify a user space docker command\n(like udocker or dx-docker) that will be used to call\n'pull' and 'run'")), ToolInput(tag="in_singularity", input_type=Boolean(optional=True), prefix="--singularity", doc=InputDocumentation(doc="[experimental] Use Singularity runtime for running\ncontainers. Requires Singularity v2.6.1+ and Linux\nwith kernel version v3.18+ or with overlayfs support\nbackported.")), ToolInput(tag="in_no_container", input_type=Boolean(optional=True), prefix="--no-container", doc=InputDocumentation(doc="Do not execute jobs in a Docker container, even when\n`DockerRequirement` is specified under `hints`.")), ToolInput(tag="in_leave_container", input_type=Boolean(optional=True), prefix="--leave-container", doc=InputDocumentation(doc="Do not delete Docker container used by jobs after they")), ToolInput(tag="in_beta_dependency_resolvers_configuration", input_type=File(optional=True), prefix="--beta-dependency-resolvers-configuration", doc=InputDocumentation(doc="Path prefix for temporary directories")), ToolInput(tag="in_tmp_outdir_prefix", input_type=File(optional=True), prefix="--tmp-outdir-prefix", doc=InputDocumentation(doc="Path prefix for intermediate output directories")), ToolInput(tag="in_force_docker_pull", input_type=Boolean(optional=True), prefix="--force-docker-pull", doc=InputDocumentation(doc="Pull latest docker image even if it is locally present")), ToolInput(tag="in_no_match_user", input_type=Boolean(optional=True), prefix="--no-match-user", doc=InputDocumentation(doc="Disable passing the current uid to `docker run --user`")), ToolInput(tag="in_no_read_only", input_type=Boolean(optional=True), prefix="--no-read-only", doc=InputDocumentation(doc="Do not set root directory in the container as read-")), ToolInput(tag="in_relax_path_checks", input_type=Boolean(optional=True), prefix="--relax-path-checks", doc=InputDocumentation(doc="Relax requirements on path names to permit spaces and\nhash characters.")), ToolInput(tag="in_default_container", input_type=String(optional=True), prefix="--default-container", doc=InputDocumentation(doc="Specify a default docker container that will be used\nif the workflow fails to specify one.")), ToolInput(tag="in_logoff", input_type=Boolean(optional=True), prefix="--logOff", doc=InputDocumentation(doc="Same as --logCritical")), ToolInput(tag="in_log_critical", input_type=Boolean(optional=True), prefix="--logCritical", doc=InputDocumentation(doc="Turn on logging at level CRITICAL and above. (default\nis INFO)")), ToolInput(tag="in_log_error", input_type=Boolean(optional=True), prefix="--logError", doc=InputDocumentation(doc="Turn on logging at level ERROR and above. (default is\nINFO)")), ToolInput(tag="in_log_warning", input_type=Boolean(optional=True), prefix="--logWarning", doc=InputDocumentation(doc="Turn on logging at level WARNING and above. (default\nis INFO)")), ToolInput(tag="in_loginfo", input_type=Boolean(optional=True), prefix="--logInfo", doc=InputDocumentation(doc="Turn on logging at level INFO and above. (default is\nINFO)")), ToolInput(tag="in_log_debug", input_type=Boolean(optional=True), prefix="--logDebug", doc=InputDocumentation(doc="Turn on logging at level DEBUG and above. (default is\nINFO)")), ToolInput(tag="in_loglevel", input_type=String(optional=True), prefix="--logLevel", doc=InputDocumentation(doc="Log at given level (may be either OFF (or CRITICAL),\nERROR, WARN (or WARNING), INFO or DEBUG). (default is\nINFO)")), ToolInput(tag="in_log_file", input_type=File(optional=True), prefix="--logFile", doc=InputDocumentation(doc="File to log in")), ToolInput(tag="in_rotating_logging", input_type=Boolean(optional=True), prefix="--rotatingLogging", doc=InputDocumentation(doc="Turn on rotating logging, which prevents log files\ngetting too big.")), ToolInput(tag="in_workdir", input_type=File(optional=True), prefix="--workDir", doc=InputDocumentation(doc="Absolute path to directory where temporary files\ngenerated during the Toil run should be placed.\nStandard output and error from batch system jobs\n(unless --noStdOutErr) will be placed in this\ndirectory. A cache directory may be placed in this\ndirectory. Temp files and folders will be placed in a\ndirectory toil-<workflowID> within workDir. The\nworkflowID is generated by Toil and will be reported\nin the workflow logs. Default is determined by the\nvariables (TMPDIR, TEMP, TMP) via mkdtemp. This\ndirectory needs to exist on all machines running jobs;\nif capturing standard output and error from batch\nsystem jobs is desired, it will generally need to be\non a shared file system. When sharing a cache between\ncontainers on a host, this directory must be shared\nbetween the containers.")), ToolInput(tag="in_no_stdout_err", input_type=Boolean(optional=True), prefix="--noStdOutErr", doc=InputDocumentation(doc="Do not capture standard output and error from batch\nsystem jobs.")), ToolInput(tag="in_stats", input_type=Boolean(optional=True), prefix="--stats", doc=InputDocumentation(doc="Records statistics about the toil workflow to be used\nby 'toil stats'.")), ToolInput(tag="in_clean", input_type=String(optional=True), prefix="--clean", doc=InputDocumentation(doc="Determines the deletion of the jobStore upon\ncompletion of the program. Choices: 'always',\n'onError','never', 'onSuccess'. The --stats option\nrequires information from the jobStore upon completion\nso the jobStore will never be deleted withthat flag.\nIf you wish to be able to restart the run, choose\n'never' or 'onSuccess'. Default is 'never' if stats is\nenabled, and 'onSuccess' otherwise")), ToolInput(tag="in_clean_workdir", input_type=String(optional=True), prefix="--cleanWorkDir", doc=InputDocumentation(doc="Determines deletion of temporary worker directory upon\ncompletion of a job. Choices: 'always', 'never',\n'onSuccess'. Default = always. WARNING: This option\nshould be changed for debugging only. Running a full\npipeline with this option could fill your disk with\nintermediate data.")), ToolInput(tag="in_cluster_stats", input_type=File(optional=True), prefix="--clusterStats", doc=InputDocumentation(doc="[CLUSTERSTATS]\nIf enabled, writes out JSON resource usage statistics\nto a file. The default location for this file is the\ncurrent working directory, but an absolute path can\nalso be passed to specify where this file should be\nwritten. This options only applies when using scalable\nbatch systems.")), ToolInput(tag="in_restart", input_type=Boolean(optional=True), prefix="--restart", doc=InputDocumentation(doc="If --restart is specified then will attempt to restart\nexisting workflow at the location pointed to by the\n--jobStore option. Will raise an exception if the\nworkflow does not exist")), ToolInput(tag="in_batch_system", input_type=String(optional=True), prefix="--batchSystem", doc=InputDocumentation(doc="The type of batch system to run the job(s) with,\ncurrently can be one of Slurm, Torque, LSF,\nKubernetes, Mesos, HTCondor, singleMachine, parasol,\ngridEngine'. default=singleMachine")), ToolInput(tag="in_disable_hot_deployment", input_type=Boolean(optional=True), prefix="--disableHotDeployment", doc=InputDocumentation(doc="Hot-deployment was renamed to auto-deployment. Option\nnow redirects to --disableAutoDeployment. Left in for\nbackwards compatibility.")), ToolInput(tag="in_disable_auto_deployment", input_type=Boolean(optional=True), prefix="--disableAutoDeployment", doc=InputDocumentation(doc="Should auto-deployment of the user script be\ndeactivated? If True, the user script/package should\nbe present at the same location on all workers.\ndefault=false")), ToolInput(tag="in_max_local_jobs", input_type=Int(optional=True), prefix="--maxLocalJobs", doc=InputDocumentation(doc="For batch systems that support a local queue for\nhousekeeping jobs (Mesos, GridEngine, htcondor, lsf,\nslurm, torque), the maximum number of these\nhousekeeping jobs to run on the local system. The\ndefault (equal to the number of cores) is a maximum of\n8 concurrent local housekeeping jobs.")), ToolInput(tag="in_manual_mem_args", input_type=Boolean(optional=True), prefix="--manualMemArgs", doc=InputDocumentation(doc="Do not add the default arguments: 'hv=MEMORY' &\n'h_vmem=MEMORY' to the qsub call, and instead rely on\nTOIL_GRIDGENGINE_ARGS to supply alternative arguments.\nRequires that TOIL_GRIDGENGINE_ARGS be set.")), ToolInput(tag="in_run_cwl_internal_jobs_on_workers", input_type=Boolean(optional=True), prefix="--runCwlInternalJobsOnWorkers", doc=InputDocumentation(doc="Whether to run CWL internal jobs (e.g. CWLScatter) on\nthe worker nodes instead of the primary node. If false\n(default), then all such jobs are run on the primary\nnode. Setting this to true can speed up the pipeline\nfor very large workflows with many sub-workflows\nand/or scatters, provided that the worker pool is\nlarge enough.")), ToolInput(tag="in_parasol_command", input_type=File(optional=True), prefix="--parasolCommand", doc=InputDocumentation(doc="The name or path of the parasol program. Will be\nlooked up on PATH unless it starts with a slash.\ndefault=parasol")), ToolInput(tag="in_parasol_max_batches", input_type=Int(optional=True), prefix="--parasolMaxBatches", doc=InputDocumentation(doc="Maximum number of job batches the Parasol batch is\nallowed to create. One batch is created for jobs with\na a unique set of resource requirements. default=1000")), ToolInput(tag="in_scale", input_type=Int(optional=True), prefix="--scale", doc=InputDocumentation(doc="A scaling factor to change the value of all submitted\ntasks's submitted cores. Used in singleMachine batch\nsystem. default=1")), ToolInput(tag="in_no_link_imports", input_type=Boolean(optional=True), prefix="--noLinkImports", doc=InputDocumentation(doc="When using a filesystem based job store, CWL input\nfiles are by default symlinked in. Specifying this\noption instead copies the files into the job store,\nwhich may protect them from being modified externally.\nWhen not specified and as long as caching is enabled,\nToil will protect the file automatically by changing\nthe permissions to read-only.")), ToolInput(tag="in_no_move_exports", input_type=File(optional=True), prefix="--noMoveExports", doc=InputDocumentation(doc="When using a filesystem based job store, output files\nare by default moved to the output directory, and a\nsymlink to the moved exported file is created at the\ninitial location. Specifying this option instead\ncopies the files into the output directory. Applies to\nfilesystem-based job stores only.")), ToolInput(tag="in_mesos_master", input_type=Float(optional=True), prefix="--mesosMaster", doc=InputDocumentation(doc="The host and port of the Mesos master separated by\ncolon. (default: 172.17.0.4:5050)")), ToolInput(tag="in_ku_bernet_es_host_path", input_type=File(optional=True), prefix="--kubernetesHostPath", doc=InputDocumentation(doc="Path on Kubernetes hosts to use as shared inter-pod\ntemp directory (default: None)")), ToolInput(tag="in_node_types", input_type=Int(optional=True), prefix="--nodeTypes", doc=InputDocumentation(doc="List of node types separated by commas. The syntax for\neach node type depends on the provisioner used. For\nthe cgcloud and AWS provisioners this is the name of\nan EC2 instance type, optionally followed by a colon\nand the price in dollars to bid for a spot instance of\nthat type, for example 'c3.8xlarge:0.42'.If no spot\nbid is specified, nodes of this type will be non-\npreemptable.It is acceptable to specify an instance as\nboth preemptable and non-preemptable, including it\ntwice in the list. In that case,preemptable nodes of\nthat type will be preferred when creating new nodes\nonce the maximum number of preemptable-nodes has\nbeenreached.")), ToolInput(tag="in_node_options", input_type=String(optional=True), prefix="--nodeOptions", doc=InputDocumentation(doc="Options for provisioning the nodes. The syntax depends\non the provisioner used. Neither the CGCloud nor the\nAWS provisioner support any node options.")), ToolInput(tag="in_min_nodes", input_type=Int(optional=True), prefix="--minNodes", doc=InputDocumentation(doc="Mininum number of nodes of each type in the cluster,\nif using auto-scaling. This should be provided as a\ncomma-separated list of the same length as the list of\nnode types. default=0")), ToolInput(tag="in_max_nodes", input_type=Int(optional=True), prefix="--maxNodes", doc=InputDocumentation(doc="Maximum number of nodes of each type in the cluster,\nif using autoscaling, provided as a comma-separated\nlist. The first value is used as a default if the list\nlength is less than the number of nodeTypes.\ndefault=10")), ToolInput(tag="in_target_time", input_type=Int(optional=True), prefix="--targetTime", doc=InputDocumentation(doc="Sets how rapidly you aim to complete jobs in seconds.\nShorter times mean more aggressive parallelization.\nThe autoscaler attempts to scale up/down so that it\nexpects all queued jobs will complete within\ntargetTime seconds. default=1800")), ToolInput(tag="in_beta_inertia", input_type=Int(optional=True), prefix="--betaInertia", doc=InputDocumentation(doc="A smoothing parameter to prevent unnecessary\noscillations in the number of provisioned nodes. This\ncontrols an exponentially weighted moving average of\nthe estimated number of nodes. A value of 0.0 disables\nany smoothing, and a value of 0.9 will smooth so much\nthat few changes will ever be made. Must be between\n0.0 and 0.9. default=0.1")), ToolInput(tag="in_scale_interval", input_type=Int(optional=True), prefix="--scaleInterval", doc=InputDocumentation(doc="The interval (seconds) between assessing if the scale\nof the cluster needs to change. default=60")), ToolInput(tag="in_preempt_able_compensation", input_type=Float(optional=True), prefix="--preemptableCompensation", doc=InputDocumentation(doc="The preference of the autoscaler to replace\npreemptable nodes with non-preemptable nodes, when\npreemptable nodes cannot be started for some reason.\nDefaults to 0.0. This value must be between 0.0 and\n1.0, inclusive. A value of 0.0 disables such\ncompensation, a value of 0.5 compensates two missing\npreemptable nodes with a non-preemptable one. A value\nof 1.0 replaces every missing pre-emptable node with a\nnon-preemptable one.")), ToolInput(tag="in_node_storage", input_type=Int(optional=True), prefix="--nodeStorage", doc=InputDocumentation(doc="Specify the size of the root volume of worker nodes\nwhen they are launched in gigabytes. You may want to\nset this if your jobs require a lot of disk space. The\ndefault value is 50.")), ToolInput(tag="in_metrics", input_type=Boolean(optional=True), prefix="--metrics", doc=InputDocumentation(doc="Enable the prometheus/grafana dashboard for monitoring\nCPU/RAM usage, queue size, and issued jobs.")), ToolInput(tag="in_default_memory", input_type=Int(optional=True), prefix="--defaultMemory", doc=InputDocumentation(doc="The default amount of memory to request for a job.\nOnly applicable to jobs that do not specify an\nexplicit value for this requirement. Standard suffixes\nlike K, Ki, M, Mi, G or Gi are supported. Default is\n2.0 Gi")), ToolInput(tag="in_default_cores", input_type=Float(optional=True), prefix="--defaultCores", doc=InputDocumentation(doc="The default number of CPU cores to dedicate a job.\nOnly applicable to jobs that do not specify an\nexplicit value for this requirement. Fractions of a\ncore (for example 0.1) are supported on some batch\nsystems, namely Mesos and singleMachine. Default is\n1.0")), ToolInput(tag="in_default_disk", input_type=Int(optional=True), prefix="--defaultDisk", doc=InputDocumentation(doc="The default amount of disk space to dedicate a job.\nOnly applicable to jobs that do not specify an\nexplicit value for this requirement. Standard suffixes\nlike K, Ki, M, Mi, G or Gi are supported. Default is\n2.0 Gi")), ToolInput(tag="in_default_preempt_able", input_type=Int(optional=True), prefix="--defaultPreemptable", doc=InputDocumentation(doc="The maximum number of CPU cores to request from the\nbatch system at any one time. Standard suffixes like\nK, Ki, M, Mi, G or Gi are supported. Default is 8.0 Ei")), ToolInput(tag="in_max_memory", input_type=Int(optional=True), prefix="--maxMemory", doc=InputDocumentation(doc="The maximum amount of memory to request from the batch\nsystem at any one time. Standard suffixes like K, Ki,\nM, Mi, G or Gi are supported. Default is 8.0 Ei")), ToolInput(tag="in_max_disk", input_type=Int(optional=True), prefix="--maxDisk", doc=InputDocumentation(doc="The maximum amount of disk space to request from the\nbatch system at any one time. Standard suffixes like\nK, Ki, M, Mi, G or Gi are supported. Default is 8.0 Ei")), ToolInput(tag="in_retry_count", input_type=Int(optional=True), prefix="--retryCount", doc=InputDocumentation(doc="Number of times to retry a failing job before giving\nup and labeling job failed. default=1")), ToolInput(tag="in_enable_unlimited_preempt_able_retries", input_type=Boolean(optional=True), prefix="--enableUnlimitedPreemptableRetries", doc=InputDocumentation(doc="If set, preemptable failures (or any failure due to an\ninstance getting unexpectedly terminated) would not\ncount towards job failures and --retryCount.")), ToolInput(tag="in_max_job_duration", input_type=Int(optional=True), prefix="--maxJobDuration", doc=InputDocumentation(doc="Maximum runtime of a job (in seconds) before we kill\nit (this is a lower bound, and the actual time before\nkilling the job may be longer).\ndefault=9223372036854775807")), ToolInput(tag="in_rescue_jobs_frequency", input_type=Int(optional=True), prefix="--rescueJobsFrequency", doc=InputDocumentation(doc="Period of time to wait (in seconds) between checking\nfor missing/overlong jobs, that is jobs which get lost\nby the batch system. Expert parameter. default=3600")), ToolInput(tag="in_disable_caching", input_type=Boolean(optional=True), prefix="--disableCaching", doc=InputDocumentation(doc="[DISABLECACHING]\nDisables caching in the file store. This flag must be\nset to use a batch system that does not support\ncaching such as Grid Engine, Parasol, LSF, or Slurm")), ToolInput(tag="in_disable_chaining", input_type=Boolean(optional=True), prefix="--disableChaining", doc=InputDocumentation(doc="Disables chaining of jobs (chaining uses one job's\nresource allocation for its successor job if\npossible).")), ToolInput(tag="in_disable_job_store_checksum_verification", input_type=Boolean(optional=True), prefix="--disableJobStoreChecksumVerification", doc=InputDocumentation(doc="Disables checksum verification for files transferred\nto/from the job store. Checksum verification is a\nsafety check to ensure the data is not corrupted\nduring transfer. Currently only supported for non-\nstreaming AWS files.")), ToolInput(tag="in_max_log_file_size", input_type=Int(optional=True), prefix="--maxLogFileSize", doc=InputDocumentation(doc="The maximum size of a job log file to keep (in bytes),\nlog files larger than this will be truncated to the\nlast X bytes. Setting this option to zero will prevent\nany truncation. Setting this option to a negative\nvalue will truncate from the beginning.Default=62.5 K")), ToolInput(tag="in_write_logs", input_type=File(optional=True), prefix="--writeLogs", doc=InputDocumentation(doc="[WRITELOGS]\nWrite worker logs received by the leader into their\nown files at the specified path. Any non-empty\nstandard output and error from failed batch system\njobs will also be written into files at this path. The\ncurrent working directory will be used if a path is\nnot specified explicitly. Note: By default only the\nlogs of failed jobs are returned to leader. Set log\nlevel to 'debug' or enable '--writeLogsFromAllJobs' to\nget logs back from successful jobs, and adjust\n'maxLogFileSize' to control the truncation limit for\nworker logs.")), ToolInput(tag="in_write_logs_gzip", input_type=Boolean(optional=True), prefix="--writeLogsGzip", doc=InputDocumentation(doc="[WRITELOGSGZIP]\nIdentical to --writeLogs except the logs files are\ngzipped on the leader.")), ToolInput(tag="in_write_logs_from_all_jobs", input_type=Boolean(optional=True), prefix="--writeLogsFromAllJobs", doc=InputDocumentation(doc="Whether to write logs from all jobs (including the\nsuccessful ones) without necessarily setting the log\nlevel to 'debug'. Ensure that either --writeLogs or\n--writeLogsGzip is set if enabling this option.")), ToolInput(tag="in_real_time_logging", input_type=Boolean(optional=True), prefix="--realTimeLogging", doc=InputDocumentation(doc="Enable real-time logging from workers to masters")), ToolInput(tag="in_sse_key", input_type=File(optional=True), prefix="--sseKey", doc=InputDocumentation(doc="Path to file containing 32 character key to be used\nfor server-side encryption on awsJobStore or\ngoogleJobStore. SSE will not be used if this flag is\nnot passed.")), ToolInput(tag="in_setenv", input_type=String(optional=True), prefix="--setEnv", doc=InputDocumentation(doc="=VALUE or NAME, -e NAME=VALUE or NAME\nSet an environment variable early on in the worker. If\nVALUE is omitted, it will be looked up in the current\nenvironment. Independently of this option, the worker\nwill try to emulate the leader's environment before\nrunning a job, except for some variables known to vary\nacross systems. Using this option, a variable can be\ninjected into the worker process itself before it is\nstarted.")), ToolInput(tag="in_service_polling_interval", input_type=Int(optional=True), prefix="--servicePollingInterval", doc=InputDocumentation(doc="Interval of time service jobs wait between polling for\nthe existence of the keep-alive flag (defailt=60)")), ToolInput(tag="in_force_docker_appliance", input_type=Boolean(optional=True), prefix="--forceDockerAppliance", doc=InputDocumentation(doc="Disables sanity checking the existence of the docker\nimage specified by TOIL_APPLIANCE_SELF, which Toil\nuses to provision mesos for autoscaling.")), ToolInput(tag="in_disable_progress", input_type=Boolean(optional=True), prefix="--disableProgress", doc=InputDocumentation(doc="Disables the progress bar shown when standard error is\na terminal.")), ToolInput(tag="in_debug_worker", input_type=Boolean(optional=True), prefix="--debugWorker", doc=InputDocumentation(doc="Experimental no forking mode for local debugging.\nSpecifically, workers are not forked and stderr/stdout\nare not redirected to the log.")), ToolInput(tag="in_disable_worker_output_capture", input_type=Boolean(optional=True), prefix="--disableWorkerOutputCapture", doc=InputDocumentation(doc="Let worker output go to worker's standard out/error\ninstead of per-job logs.")), ToolInput(tag="in_bad_worker", input_type=Float(optional=True), prefix="--badWorker", doc=InputDocumentation(doc="For testing purposes randomly kill 'badWorker'\nproportion of jobs using SIGKILL, default=0.0")), ToolInput(tag="in_bad_worker_fail_interval", input_type=Float(optional=True), prefix="--badWorkerFailInterval", doc=InputDocumentation(doc="When killing the job pick uniformly within the\ninterval from 0.0 to 'badWorkerFailInterval' seconds\nafter the worker starts, default=0.01")), ToolInput(tag="in_provenance", input_type=Directory(optional=True), prefix="--provenance", doc=InputDocumentation(doc="Save provenance to specified folder as a Research\nObject that captures and aggregates workflow execution\nand data products.")), ToolInput(tag="in_enable_user_provenance", input_type=Boolean(optional=True), prefix="--enable-user-provenance", doc=InputDocumentation(doc="Record user account info as part of provenance.")), ToolInput(tag="in_disable_user_provenance", input_type=Boolean(optional=True), prefix="--disable-user-provenance", doc=InputDocumentation(doc="Do not record user account info in provenance.")), ToolInput(tag="in_enable_host_provenance", input_type=Boolean(optional=True), prefix="--enable-host-provenance", doc=InputDocumentation(doc="Record host info as part of provenance.")), ToolInput(tag="in_disable_host_provenance", input_type=Boolean(optional=True), prefix="--disable-host-provenance", doc=InputDocumentation(doc="Do not record host info in provenance.")), ToolInput(tag="in_or_cid", input_type=Int(optional=True), prefix="--orcid", doc=InputDocumentation(doc="Record user ORCID identifier as part of provenance,\ne.g. https://orcid.org/0000-0002-1825-0097 or\n0000-0002-1825-0097. Alternatively the environment\nvariable ORCID may be set.")), ToolInput(tag="in_full_name", input_type=String(optional=True), prefix="--full-name", doc=InputDocumentation(doc="Record full name of user as part of provenance, e.g.\nJosiah Carberry. You may need to use shell quotes to\npreserve spaces. Alternatively the environment\nvariable CWL_FULL_NAME may be set.\n")), ToolInput(tag="in_cwl_tool", input_type=String(), position=0, doc=InputDocumentation(doc="cwljob")), ToolInput(tag="in_exit", input_type=String(), position=0, doc=InputDocumentation(doc="--preserve-environment VAR1 VAR2 [VAR1 VAR2 ...]")), ToolInput(tag="in_command_line_tools", input_type=String(), position=0, doc=InputDocumentation(doc="--preserve-entire-environment")), ToolInput(tag="in_command_line_tools_dot", input_type=String(), position=0, doc=InputDocumentation(doc="--destBucket DESTBUCKET")), ToolInput(tag="in_only", input_type=String(), position=0, doc=InputDocumentation(doc="--strict-memory-limit")), ToolInput(tag="in_job_store", input_type=String(), position=0, doc=InputDocumentation(doc="The location of the job store for the workflow. A job\nstore holds persistent information about the jobs and\nfiles in a workflow. If the workflow is run with a\ndistributed batch system, the job store must be\naccessible by all worker nodes. Depending on the\ndesired job store implementation, the location should\nbe formatted according to one of the following\nschemes: file:<path> where <path> points to a\ndirectory on the file systen aws:<region>:<prefix>\nwhere <region> is the name of an AWS region like us-\nwest-2 and <prefix> will be prepended to the names of\nany top-level AWS resources in use by job store, e.g.\nS3 buckets. google:<project_id>:<prefix> TODO: explain\nFor backwards compatibility, you may also specify\n./foo (equivalent to file:./foo or just file:foo) or\n/bar (equivalent to file:/bar).")), ToolInput(tag="in_provisioning_dot", input_type=String(), position=0, doc=InputDocumentation(doc="--provisioner {aws,gce}\nThe provisioner for cluster auto-scaling. The\ncurrently supported choices are'gce', or 'aws'. The\ndefault is None."))], outputs=[ToolOutput(tag="out_tmp_outdir_prefix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_tmp_outdir_prefix", type_hint=File()), doc=OutputDocumentation(doc="Path prefix for intermediate output directories")), ToolOutput(tag="out_workdir", output_type=File(optional=True), selector=InputSelector(input_to_select="in_workdir", type_hint=File()), doc=OutputDocumentation(doc="Absolute path to directory where temporary files\ngenerated during the Toil run should be placed.\nStandard output and error from batch system jobs\n(unless --noStdOutErr) will be placed in this\ndirectory. A cache directory may be placed in this\ndirectory. Temp files and folders will be placed in a\ndirectory toil-<workflowID> within workDir. The\nworkflowID is generated by Toil and will be reported\nin the workflow logs. Default is determined by the\nvariables (TMPDIR, TEMP, TMP) via mkdtemp. This\ndirectory needs to exist on all machines running jobs;\nif capturing standard output and error from batch\nsystem jobs is desired, it will generally need to be\non a shared file system. When sharing a cache between\ncontainers on a host, this directory must be shared\nbetween the containers.")), ToolOutput(tag="out_cluster_stats", output_type=File(optional=True), selector=InputSelector(input_to_select="in_cluster_stats", type_hint=File()), doc=OutputDocumentation(doc="[CLUSTERSTATS]\nIf enabled, writes out JSON resource usage statistics\nto a file. The default location for this file is the\ncurrent working directory, but an absolute path can\nalso be passed to specify where this file should be\nwritten. This options only applies when using scalable\nbatch systems.")), ToolOutput(tag="out_no_move_exports", output_type=File(optional=True), selector=InputSelector(input_to_select="in_no_move_exports", type_hint=File()), doc=OutputDocumentation(doc="When using a filesystem based job store, output files\nare by default moved to the output directory, and a\nsymlink to the moved exported file is created at the\ninitial location. Specifying this option instead\ncopies the files into the output directory. Applies to\nfilesystem-based job stores only.")), ToolOutput(tag="out_write_logs", output_type=File(optional=True), selector=InputSelector(input_to_select="in_write_logs", type_hint=File()), doc=OutputDocumentation(doc="[WRITELOGS]\nWrite worker logs received by the leader into their\nown files at the specified path. Any non-empty\nstandard output and error from failed batch system\njobs will also be written into files at this path. The\ncurrent working directory will be used if a path is\nnot specified explicitly. Note: By default only the\nlogs of failed jobs are returned to leader. Set log\nlevel to 'debug' or enable '--writeLogsFromAllJobs' to\nget logs back from successful jobs, and adjust\n'maxLogFileSize' to control the truncation limit for\nworker logs."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Toil_Cwl_Runner_V0_1_0().translate("wdl", allow_empty_container=True)

